@@ -101,7 +101,7 @@ def _search_result_cachekey(fun, flexitopic):
     return ckey
 
 
-#@ram.cache(_search_result_cachekey)
+@ram.cache(_search_result_cachekey)
 def get_search_results(flexitopic):
     form = flexitopic.request.form
 
